@@ -19,8 +19,12 @@ except KeyError:
 
 def ask_aeda(reg_number, log_level=None):
     url = "https://aedacar.azurewebsites.net/api/car"
-    params = {"code": "BzaCA1bdqU21cfZVn8r3KJwaoivzaOla7o6sLa-qD0elAzFulXlzyA==", "username": username, "apiKey": api_key, "regNumber": reg_number, 'logLevel': log_level}
-    r = requests.get(url, params=params)
+    params = {"code": "BzaCA1bdqU21cfZVn8r3KJwaoivzaOla7o6sLa-qD0elAzFulXlzyA==", 
+              "username": username, 
+              "regNumber": reg_number, 
+              "logLevel": log_level}
+    headers={"api-key": api_key}
+    r = requests.get(url, params=params, headers=headers)
     try:
         r.raise_for_status()
     except requests.exceptions.HTTPError as errh:
@@ -40,6 +44,8 @@ def ask_aeda(reg_number, log_level=None):
         body = json.loads(body)
     except json.decoder.JSONDecodeError:
         print("Error in json")
+    print(r.status_code)
+    print(r.reason)
     return body
 
 
